package com.srs.teacher.mapper;

import java.util.List;

import com.srs.teacher.domain.SysTeacherKpiFillingStuMgt;
import com.srs.teacher.domain.SysTeacherStuActivityMaterials;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

/**
 * 学生开展活动佐证材料Mapper接口
 *
 * @author chc
 * @date 2024-06-05
 */
public interface SysTeacherStuActivityMaterialsMapper extends BaseMapper<SysTeacherStuActivityMaterials> {
    /**
     * 查询学生开展活动佐证材料
     *
     * @param id 学生开展活动佐证材料主键
     * @return 学生开展活动佐证材料
     */
    public SysTeacherStuActivityMaterials selectSysTeacherStuActivityMaterialsById(Long id);

    /**
     * 查询学生开展活动佐证材料列表
     *
     * @param sysTeacherStuActivityMaterials 学生开展活动佐证材料
     * @return 学生开展活动佐证材料集合
     */
    List<SysTeacherStuActivityMaterials> selectSysTeacherStuActivityMaterialsList(SysTeacherStuActivityMaterials sysTeacherStuActivityMaterials);

    /**
     * 查根据辅导员名称、年份 月份 查询
     *
     * @param fdyName 辅导员名称
     * @return 生开展活动佐证材料集合
     */
    List<SysTeacherStuActivityMaterials> selectSysTeacherStuActivityMaterialsByFdyName(@Param("fdyName") String fdyName, @Param("fillingYear") String fillingYear, @Param("fillingMonth") String fillingMonth);


    /**
     * 新增学生开展活动佐证材料
     *
     * @param sysTeacherStuActivityMaterials 学生开展活动佐证材料
     * @return 结果
     */
    int insertSysTeacherStuActivityMaterials(SysTeacherStuActivityMaterials sysTeacherStuActivityMaterials);

    /**
     * 修改学生开展活动佐证材料
     *
     * @param sysTeacherStuActivityMaterials 学生开展活动佐证材料
     * @return 结果
     */
    int updateSysTeacherStuActivityMaterials(SysTeacherStuActivityMaterials sysTeacherStuActivityMaterials);

    /**
     * 删除学生开展活动佐证材料
     *
     * @param id 学生开展活动佐证材料主键
     * @return 结果
     */
    int deleteSysTeacherStuActivityMaterialsById(Long id);

    /**
     * 批量删除学生开展活动佐证材料
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysTeacherStuActivityMaterialsByIds(Long[] ids);
}
