package com.srs.web.controller.teacher;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.srs.common.annotation.RepeatSubmit;
import com.srs.teacher.domain.SysTeacherKpiFillingStuMgt;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;

import com.srs.teacher.domain.SysTeacherStuActivityMaterials;
import com.srs.teacher.service.ISysTeacherStuActivityMaterialsService;
import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.common.enums.BusinessType;
import com.srs.common.annotation.Log;
import com.srs.common.core.page.TableDataInfo;

/**
 * 学生开展活动佐证材料Controller
 *
 * @author chc
 * @date 2024-06-05
 */
@RestController
@RequestMapping("/teacher/stuActivityMaterials")
@Api(value = "学生开展活动佐证材料管理", tags = "学生开展活动佐证材料管理")
public class SysTeacherStuActivityMaterialsController extends BaseController {
    @Autowired
    private ISysTeacherStuActivityMaterialsService sysTeacherStuActivityMaterialsService;

    /**
     * 查询学生开展活动佐证材料列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:list')")
    @GetMapping("/list")
    @ApiOperation("查询学生开展活动佐证材料列表")
    public TableDataInfo list(SysTeacherStuActivityMaterials sysTeacherStuActivityMaterials) {
        startPage();
        List<SysTeacherStuActivityMaterials> list = sysTeacherStuActivityMaterialsService.selectSysTeacherStuActivityMaterialsList(sysTeacherStuActivityMaterials);
        return getDataTable(list);
    }

    /**
     * 根据辅导员名称、年份 月份 查询详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:list')")
    @GetMapping("/getByFdyNameAndYearAndMonth")
    @ApiOperation("根据名称年月查询学生开展活动佐证材料列表")
    public TableDataInfo getByFdyNameAndYearAndMonth(@RequestParam String fdyName, @RequestParam String fillingYear, @RequestParam String fillingMonth) {
        startPage();
        List<SysTeacherStuActivityMaterials> list = sysTeacherStuActivityMaterialsService.selectSysTeacherStuActivityMaterialsByFdyName(fdyName, fillingYear, fillingMonth);
        return getDataTable(list);
    }

    /**
     * 导出学生开展活动佐证材料列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:export')")
    @Log(title = "学生开展活动佐证材料", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation("导出学生开展活动佐证材料列表")
    public void export(HttpServletResponse response, SysTeacherStuActivityMaterials sysTeacherStuActivityMaterials) {
        List<SysTeacherStuActivityMaterials> list = sysTeacherStuActivityMaterialsService.selectSysTeacherStuActivityMaterialsList(sysTeacherStuActivityMaterials);
        ExcelUtil<SysTeacherStuActivityMaterials> util = new ExcelUtil<SysTeacherStuActivityMaterials>(SysTeacherStuActivityMaterials.class);
        util.exportExcel(response, list, "学生开展活动佐证材料数据");
    }

    /**
     * 获取学生开展活动佐证材料详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取学生开展活动佐证材料详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sysTeacherStuActivityMaterialsService.selectSysTeacherStuActivityMaterialsById(id));
    }

    /**
     * 新增学生开展活动佐证材料
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:add')")
    @Log(title = "学生开展活动佐证材料", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增学生开展活动佐证材料")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult add(@RequestBody SysTeacherStuActivityMaterials sysTeacherStuActivityMaterials) {
        return toAjax(sysTeacherStuActivityMaterialsService.insertSysTeacherStuActivityMaterials(sysTeacherStuActivityMaterials));
    }

    /**
     * 修改学生开展活动佐证材料
     */
    @PreAuthorize("@ss.hasAnyPermi('teacher:stuActivityMaterials:edit,teacher:stuActivityMaterials:add')")
    @Log(title = "学生开展活动佐证材料", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    @ApiOperation("修改学生开展活动佐证材料")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult edit(@RequestBody SysTeacherStuActivityMaterials sysTeacherStuActivityMaterials) {
        return toAjax(sysTeacherStuActivityMaterialsService.updateSysTeacherStuActivityMaterials(sysTeacherStuActivityMaterials));
    }

    /**
     * 删除学生开展活动佐证材料
     */
    @PreAuthorize("@ss.hasPermi('teacher:stuActivityMaterials:remove')")
    @Log(title = "学生开展活动佐证材料", businessType = BusinessType.DELETE)
    @PostMapping("/{ids}")
    @ApiOperation("删除学生开展活动佐证材料")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sysTeacherStuActivityMaterialsService.deleteSysTeacherStuActivityMaterialsByIds(ids));
    }
}
